@@ -874,6 +874,38 @@ const MASK_GEN_ALGORITHM_TAG: rsa::pkcs8::der::TagNumber =
 const SALT_LENGTH_TAG: rsa::pkcs8::der::TagNumber =
   rsa::pkcs8::der::TagNumber::new(2);
 
+lazy_static! {
+  // Default HashAlgorithm for RSASSA-PSS-params (sha1)
+  //
+  // sha1 HashAlgorithm ::= {
+  //   algorithm   id-sha1,
+  //   parameters  SHA1Parameters : NULL
+  // }
+  //
+  // SHA1Parameters ::= NULL
+  static ref SHA1_HASH_ALGORITHM: rsa::pkcs8::AlgorithmIdentifier<'static> = rsa::pkcs8::AlgorithmIdentifier {
+    // id-sha1
+    oid: ID_SHA1_OID,
+    // NULL
+    parameters: Some(asn1::Any::from(asn1::Null)),
+  };
+
+  // TODO(@littledivy): `pkcs8` should provide AlgorithmIdentifier to Any conversion.
+  static ref ENCODED_SHA1_HASH_ALGORITHM: Vec<u8> = SHA1_HASH_ALGORITHM.to_vec().unwrap();
+  // Default MaskGenAlgrithm for RSASSA-PSS-params (mgf1SHA1)
+  //
+  // mgf1SHA1 MaskGenAlgorithm ::= {
+  //   algorithm   id-mgf1,
+  //   parameters  HashAlgorithm : sha1
+  // }
+  static ref MGF1_SHA1_MASK_ALGORITHM: rsa::pkcs8::AlgorithmIdentifier<'static> = rsa::pkcs8::AlgorithmIdentifier {
+    // id-mgf1
+    oid: ID_MFG1,
+    // sha1
+    parameters: Some(asn1::Any::from_der(&ENCODED_SHA1_HASH_ALGORITHM).unwrap()),
+  };
+}
+
 impl<'a> TryFrom<rsa::pkcs8::der::asn1::Any<'a>>
   for PssPrivateKeyParameters<'a>
 {
@@ -887,13 +919,13 @@ impl<'a> TryFrom<rsa::pkcs8::der::asn1::Any<'a>>
         .context_specific(HASH_ALGORITHM_TAG)?
         .map(TryInto::try_into)
         .transpose()?
-        .unwrap();
+        .unwrap_or(*SHA1_HASH_ALGORITHM);
 
       let mask_gen_algorithm = decoder
         .context_specific(MASK_GEN_ALGORITHM_TAG)?
         .map(TryInto::try_into)
         .transpose()?
-        .unwrap();
+        .unwrap_or(*MGF1_SHA1_MASK_ALGORITHM);
 
       let salt_length = decoder
         .context_specific(SALT_LENGTH_TAG)?
@@ -1068,13 +1100,20 @@ pub async fn op_crypto_import_key(
             RSA_ENCRYPTION_OID => None,
             // id-RSASSA-PSS
             RSASSA_PSS_OID => {
-              // TODO(@littledivy): NotSupported error
               let params = PssPrivateKeyParameters::try_from(
                 pk_info.algorithm.parameters.ok_or_else(|| {
-                  type_error("Malformed parameters".to_string())
+                  custom_error(
+                    "DOMExceptionNotSupportedError",
+                    "Malformed parameters".to_string(),
+                  )
                 })?,
               )
-              .map_err(|_| type_error("Malformed parameters".to_string()))?;
+              .map_err(|_| {
+                custom_error(
+                  "DOMExceptionNotSupportedError",
+                  "Malformed parameters".to_string(),
+                )
+              })?;
 
               let hash_alg = params.hash_algorithm;
               let hash = match hash_alg.oid {
@@ -1095,8 +1134,8 @@ pub async fn op_crypto_import_key(
               };
 
               if params.mask_gen_algorithm.oid != ID_MFG1 {
-                // TODO(@littledivy): NotSupportedError
-                return Err(type_error(
+                return Err(custom_error(
+                  "DOMExceptionNotSupportedError",
                   "Unsupported hash algorithm".to_string(),
                 ));
               }
@@ -1175,13 +1214,20 @@ pub async fn op_crypto_import_key(
             RSA_ENCRYPTION_OID => None,
             // id-RSAES-OAEP
             RSAES_OAEP_OID => {
-              // TODO(@littledivy): NotSupported error
               let params = OaepPrivateKeyParameters::try_from(
                 pk_info.algorithm.parameters.ok_or_else(|| {
-                  type_error("Malformed parameters".to_string())
+                  custom_error(
+                    "DOMExceptionNotSupportedError",
+                    "Malformed parameters".to_string(),
+                  )
                 })?,
               )
-              .map_err(|_| type_error("Malformed parameters".to_string()))?;
+              .map_err(|_| {
+                custom_error(
+                  "DOMExceptionNotSupportedError",
+                  "Malformed parameters".to_string(),
+                )
+              })?;
 
               let hash_alg = params.hash_algorithm;
               let hash = match hash_alg.oid {
@@ -1202,8 +1248,8 @@ pub async fn op_crypto_import_key(
               };
 
               if params.mask_gen_algorithm.oid != ID_MFG1 {
-                // TODO(@littledivy): NotSupportedError
-                return Err(type_error(
+                return Err(custom_error(
+                  "DOMExceptionNotSupportedError",
                   "Unsupported hash algorithm".to_string(),
                 ));
               }
